@@ -291,7 +291,7 @@ def validate_provided(value, name, causes=[]):
 
     test = not bool(value)
     if test:
-        Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
+        print(CLI_MESSAGES['TryHelp'])
         if causes:
             raise DSOException(CLI_MESSAGES['ArgumentsProvidedBecause'].format(', '.join(causes), name))
         else:
@@ -306,7 +306,7 @@ def validate_all_provided(values, names, causes=[]):
 
     test = not reduce(lambda x, y: bool(x) and bool(y), values)
     if test:
-        Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
+        print(CLI_MESSAGES['TryHelp'])
         if causes:
             raise DSOException(CLI_MESSAGES['ArgumentsAllProvidedBecause'].format(', '.join(causes), ', '.join(names)))
         else:
@@ -321,7 +321,7 @@ def validate_not_all_provided(values, names, causes=[]):
 
     test = reduce(lambda x, y: bool(x) and bool(y), values)
     if test:
-        Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
+        print(CLI_MESSAGES['TryHelp'])
         if causes:
             raise DSOException(CLI_MESSAGES['ArgumentsNotAllProvidedBecause'].format(', '.join(causes), ', '.join(names)))
         else:
@@ -337,7 +337,7 @@ def validate_none_provided(values, names, causes=[]):
 
     test = reduce(lambda x, y: bool(x) or bool(y), values)
     if test:
-        Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
+        print(CLI_MESSAGES['TryHelp'])
         if causes:
             raise DSOException(CLI_MESSAGES['ArgumentsNoneProvidedBecause'].format(', '.join(causes), ', '.join(names)))
         else:
@@ -352,7 +352,7 @@ def validate_at_least_one_provided(values, names, causes=[]):
 
     test = not reduce(lambda x, y: bool(x) or bool(y), values)
     if test:
-        Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
+        print(CLI_MESSAGES['TryHelp'])
         if causes:
             raise DSOException(CLI_MESSAGES['ArgumentsAtLeastOneProvidedBecause'].format(', '.join(causes), ', '.join(names)))
         else:
@@ -373,7 +373,7 @@ def validate_query_argument(query, query_all, default_query):
     
     validate_not_all_provided([query, query_all], ["'-q' / '--query'", "'-a' / '--query-all'"])
     # if query and query_all:
-    #     Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
+    #     print(CLI_MESSAGES['TryHelp'])
     #     raise DSOException((CLI_MESSAGES['ArgumentsMutualExclusive'].format(""'-q' / '--query' + casue)", '-a' / '--query-all'"))
 
     if query_all:
@@ -393,7 +393,7 @@ def validate_query_argument(query, query_all, default_query):
 
 
 
-def convert_context_overrides(namespace, project, application):
+def transform_context_overrides(namespace, project, application):
     result = ''
     if namespace: 
         result += f"namespace={namespace},"
@@ -409,6 +409,6 @@ def convert_context_overrides(namespace, project, application):
         result += f"application={application},"
     elif 'DSO_APPLICATION' in os.environ:
         Logger.debug("Environment variable 'DSO_APPLICATION' found.")
-        result += f"application={os.getenv('DSO_APPLICATION')},"    
+        result += f"application={os.getenv('DSO_APPLICATION')},"
     
     return result
