@@ -6,6 +6,7 @@ from .stages import Stages
 from dsocli.file_utils import *
 from dsocli.exceptions import DSOException
 from dsocli.dict_utils import *
+from dsocli.appconfig import AppConfig
 
 
 
@@ -17,9 +18,9 @@ def get_local_path(context, key=None, path_prefix=''):
     return os.path.join(path_prefix.replace('/', os.sep), context.get_path(key).replace('/', os.sep)[1:])
 
 
-def get_parameter_store_path(config, store_name, path_prefix='', create=True):
-    path = os.path.join(get_local_path(context=config.context, key=None, path_prefix=path_prefix), store_name)
-    fullPath = os.path.join(config.working_dir, path)
+def get_parameter_store_path(store_name, path_prefix='', create=True):
+    path = os.path.join(get_local_path(context=AppConfig.context, key=None, path_prefix=path_prefix), store_name)
+    fullPath = os.path.join(AppConfig.working_dir, path)
     if not os.path.exists(fullPath):
         if create:
             os.makedirs(os.path.dirname(fullPath), exist_ok=True)
@@ -35,7 +36,7 @@ def get_context_hierachy_local_paths(context, path_prefix='', ignore_stage=False
     return result
 
 
-def load_templates_from_path(result, config, path, path_prefix='', include_contents=False, filter=None):
+def load_templates_from_path(result, path, path_prefix='', include_contents=False, filter=None):
     for pth, subdirs, files in os.walk(path):
         for name in files:
             filePath = os.path.join(pth, name)
@@ -44,8 +45,8 @@ def load_templates_from_path(result, config, path, path_prefix='', include_conte
             key = filePath[len(path)+1:].replace(os.sep, '/')
             if filter and not re.match(filter, key): continue
             if key in result:
-                Logger.warn(f"Inherited template '{key}' has been overridden.")
-            ctx_path = os.path.abspath(filePath)[len(os.path.abspath(config.working_dir)) + 1 + len(path_prefix):].replace(os.sep, '/')
+                Logger.warn(f"Inherited template '{key}' was overridden.")
+            ctx_path = os.path.abspath(filePath)[len(os.path.abspath(AppConfig.working_dir)) + 1 + len(path_prefix):].replace(os.sep, '/')
             ctx = Context(*Contexts.parse_path(ctx_path)[0:4])
             result[key] = {
                 'Stage': ctx.short_stage,
@@ -66,32 +67,32 @@ def load_templates_from_path(result, config, path, path_prefix='', include_conte
     return result
 
 
-def load_context_templates(config, path_prefix='', uninherited=False, include_contents=False, filter=None):
+def load_context_templates(path_prefix='', uninherited=False, include_contents=False, filter=None):
     ### get templates in normal order (top to bottom)
-    paths = get_context_hierachy_local_paths(context=config.context, path_prefix=path_prefix, uninherited=uninherited)
+    paths = get_context_hierachy_local_paths(context=AppConfig.context, path_prefix=path_prefix, uninherited=uninherited)
     templates = {}
     for path in paths:
         Logger.debug(f"Loading templates: path={path}")
-        load_templates_from_path(result=templates, config=config, path=os.path.join(config.working_dir, path), path_prefix=path_prefix, include_contents=include_contents, filter=filter)
+        load_templates_from_path(result=templates, path=os.path.join(AppConfig.working_dir, path), path_prefix=path_prefix, include_contents=include_contents, filter=filter)
 
     return templates
 
 
-def locate_template_in_context_hierachy(config, key, path_prefix='', include_contents=False, uninherited=False):
+def locate_template_in_context_hierachy(key, path_prefix='', include_contents=False, uninherited=False):
     templates = {}
     ### get templates in reverse order (more specific to general)
-    paths = get_context_hierachy_local_paths(context=config.context, path_prefix=path_prefix, uninherited=uninherited, reverse=True)
+    paths = get_context_hierachy_local_paths(context=AppConfig.context, path_prefix=path_prefix, uninherited=uninherited, reverse=True)
     for path in paths:
-        load_templates_from_path(result=templates, config=config, path=os.path.join(config.working_dir, path), path_prefix=path_prefix, include_contents=include_contents, filter=f"^{key}$")
+        load_templates_from_path(result=templates, path=os.path.join(AppConfig.working_dir, path), path_prefix=path_prefix, include_contents=include_contents, filter=f"^{key}$")
         if key in templates: break
 
     return templates
 
 
-def add_local_template(config, key, path_prefix, contents):
-    path = get_local_path(context=config.context, key=key, path_prefix=path_prefix)
+def add_local_template(key, path_prefix, contents):
+    path = get_local_path(context=AppConfig.context, key=key, path_prefix=path_prefix)
     Logger.debug(f"Adding local template: path={path}")
-    fullPath = os.path.join(config.working_dir, path)
+    fullPath = os.path.join(AppConfig.working_dir, path)
     os.makedirs(os.path.dirname(fullPath), exist_ok=True)
     with open(fullPath, 'w', encoding='utf-8') as f:
         f.write(contents)
@@ -117,14 +118,14 @@ def delete_local_template(path):
         os.remove(path)
 
 
-def load_parameter_store(result, config, path, path_prefix='', filter=None):
-    fullPath = os.path.join(config.working_dir, path)
+def load_parameter_store(result, path, path_prefix='', filter=None):
+    fullPath = os.path.join(AppConfig.working_dir, path)
     if not os.path.exists(fullPath): return result
     parameters = flatten_dict(input=load_file(fullPath))
     for key, value in parameters.items():
         if filter and not re.match(filter, key): continue
         if key in result:
-            Logger.warn(f"Inherited parameter '{key}' has been overridden.")
+            Logger.warn(f"Inherited parameter '{key}' was overridden.")
         ctx_path = path[len(path_prefix):].replace(os.sep, '/')
         ctx = Context(*Contexts.parse_path(ctx_path)[0:4])
         result[key] = {
@@ -163,34 +164,34 @@ def get_context_hierachy_parameter_stores(context, store_name, path_prefix='', u
     return stores
 
 
-def load_context_local_parameters(config, store_name, path_prefix='', uninherited=False, filter=None):
+def load_context_local_parameters(store_name, path_prefix='', uninherited=False, filter=None):
     ### get stores in normal order (top to bottom)
-    stores = get_context_hierachy_parameter_stores(context=config.context, store_name=store_name, path_prefix=path_prefix, uninherited=uninherited)
+    stores = get_context_hierachy_parameter_stores(context=AppConfig.context, store_name=store_name, path_prefix=path_prefix, uninherited=uninherited)
     parameters = {}
     for store in stores:
         Logger.debug(f"Loading store: path={store['Path']}")
-        load_parameter_store(result=parameters, config=config, path=store['Path'], path_prefix=path_prefix, filter=filter)
+        load_parameter_store(result=parameters, path=store['Path'], path_prefix=path_prefix, filter=filter)
 
     return parameters
 
 
-def locate_parameter_in_context_hierachy(config, key, store_name, path_prefix='', uninherited=False):
+def locate_parameter_in_context_hierachy(key, store_name, path_prefix='', uninherited=False):
     ### get stores in reverse order (more specific to general)
-    stores = get_context_hierachy_parameter_stores(context=config.context, store_name=store_name, path_prefix=path_prefix, uninherited=uninherited, reverse=True)
+    stores = get_context_hierachy_parameter_stores(context=AppConfig.context, store_name=store_name, path_prefix=path_prefix, uninherited=uninherited, reverse=True)
     parameters = {}
     for store_name in stores:
-        Logger.debug(f"Loading store_name: path={store_name['Path']}")
+        Logger.debug(f"Loading store: path={store_name['Path']}")
         if os.path.exists(store_name['Path']):
-            load_parameter_store(result=parameters, config=config, path=store_name['Path'], path_prefix=path_prefix, filter=f"^{key}$")
+            load_parameter_store(result=parameters, path=store_name['Path'], path_prefix=path_prefix, filter=f"^{key}$")
             if key in parameters: break
 
     return parameters
 
 
-def add_local_parameter(config, key, value, store_name, path_prefix=''):
-    path = get_parameter_store_path(config=config, store_name=store_name, path_prefix=path_prefix)
+def add_local_parameter(key, value, store_name, path_prefix=''):
+    path = get_parameter_store_path(store_name=store_name, path_prefix=path_prefix)
     Logger.debug(f"Local parameter store: path={path}")
-    fullPath = os.path.join(config.working_dir, path)
+    fullPath = os.path.join(AppConfig.working_dir, path)
     params = load_file(file_path=fullPath)
     set_dict_value(dic=params, keys=key.split('.'), value=value, overwrite_parent=False, overwrite_children=False)
     save_data(data=params, file_path=fullPath)
@@ -199,8 +200,8 @@ def add_local_parameter(config, key, value, store_name, path_prefix=''):
     result = {
         'Key': key,
         'Value': value,
-        'Stage': config.short_stage,
-        'Scope': config.context.scope_translation,
+        'Stage': AppConfig.short_stage,
+        'Scope': AppConfig.context.scope_translation,
         'Origin': {
             'Namespace': ctx.namespace,
             'Project': ctx.project,
