@@ -1,6 +1,6 @@
 import os
 from dsocli.logger import Logger
-from dsocli.config import Configs
+from dsocli.appconfig import AppConfig
 from dsocli.providers import Providers
 from dsocli.templates import TemplateProvider
 from dsocli.stages import Stages
@@ -12,7 +12,7 @@ from dsocli.settings import *
 
 
 __default_spec = {
-    'path': os.path.join(Configs.config_dir, 'templates'),
+    'path': os.path.join(AppConfig.config_dir, 'templates'),
 }
 
 
@@ -29,7 +29,7 @@ class LocalTemplateProvider(TemplateProvider):
 
     @property
     def root_dir(self):
-        return self.config.template_spec('path')
+        return AppConfig.template_spec('path')
 
 
     def get_path_prefix(self):
@@ -37,10 +37,9 @@ class LocalTemplateProvider(TemplateProvider):
         return self.root_dir
 
 
-    def list(self, config, uninherited=False, include_contents=False, filter=None):
-        self.config = config
-        Logger.debug(f"Listing local parameters: namespace={config.namespace}, project={config.project}, application={config.application}, stage={config.stage}")
-        templates = load_context_templates(config=config, path_prefix=self.get_path_prefix(), uninherited=uninherited, include_contents=include_contents, filter=filter)
+    def list(self, uninherited=False, include_contents=False, filter=None):
+        Logger.debug(f"Listing local templates: namespace={AppConfig.namespace}, project={AppConfig.project}, application={AppConfig.application}, stage={AppConfig.stage}")
+        templates = load_context_templates(path_prefix=self.get_path_prefix(), uninherited=uninherited, include_contents=include_contents, filter=filter)
         result = {'Templates': []}
         for key, details in templates.items():
             item = {'Key': key}
@@ -49,29 +48,27 @@ class LocalTemplateProvider(TemplateProvider):
         return result
 
 
-    def add(self, config, key, contents, render_path=None):
-        self.config = config
-        if not Stages.is_default(config.stage) and not ALLOW_STAGE_TEMPLATES:
+    def add(self, key, contents, render_path=None):
+        if not Stages.is_default(AppConfig.stage) and not ALLOW_STAGE_TEMPLATES:
             raise DSOException(f"Templates may not be added to stage scopes, as the feature is currently disabled. It may be enabled by adding 'ALLOW_STAGE_TEMPLATES=yes' to the DSO global settings, or adding environment variable 'DSO_ALLOW_STAGE_TEMPLATES=yes'.")
-        Logger.debug(f"Adding local template '{key}': namespace={config.namespace}, project={config.project}, application={config.application}, stage={config.stage}")
-        response = add_local_template(config=config, key=key, path_prefix=self.get_path_prefix(), contents=contents)
+        Logger.debug(f"Adding local template '{key}': namespace={AppConfig.namespace}, project={AppConfig.project}, application={AppConfig.application}, stage={AppConfig.stage}")
+        response = add_local_template(key=key, path_prefix=self.get_path_prefix(), contents=contents)
         result = {
                 'Key': key,
-                'Stage': Stages.shorten(config.stage),
+                'Stage': Stages.shorten(AppConfig.stage),
                 'Origin': response['Origin'], 
                 'Path': response['Path'],
             }
         return result
 
 
-    def get(self, config, key, revision=None):
-        self.config = config
+    def get(self, key, revision=None):
         if revision:
             Logger.warn(f"Template provider 'local/v1' does not support versioning.")
-        Logger.debug(f"Getting template '{key}': namespace={config.namespace}, project={config.project}, application={config.application}, stage={config.stage}")
-        found = locate_template_in_context_hierachy(config=config, key=key, path_prefix=self.get_path_prefix(), include_contents=True)
+        Logger.debug(f"Getting template '{key}': namespace={AppConfig.namespace}, project={AppConfig.project}, application={AppConfig.application}, stage={AppConfig.stage}")
+        found = locate_template_in_context_hierachy(key=key, path_prefix=self.get_path_prefix(), include_contents=True)
         if not found:
-            raise DSOException(f"Template '{key}' not found nor inherited in the given context: stage={config.short_stage}")
+            raise DSOException(f"Template '{key}' not found nor inherited in the given context: stage={AppConfig.short_stage}")
         result = {
                 'Key': key, 
             }
@@ -79,13 +76,12 @@ class LocalTemplateProvider(TemplateProvider):
         return result
 
 
-    def history(self, config, key, include_contents=False):
-        self.config = config
+    def history(self, key, include_contents=False):
         Logger.warn(f"Template provider 'local/v1' does not support versioning.")
-        Logger.debug(f"Getting template '{key}': namesape={config.namespace}, project={config.project}, application={config.application}, stage={config.stage}")
-        found = locate_template_in_context_hierachy(config=config, key=key, path_prefix=self.get_path_prefix(), include_contents=True)
+        Logger.debug(f"Getting template '{key}': namesape={AppConfig.namespace}, project={AppConfig.project}, application={AppConfig.application}, stage={AppConfig.stage}")
+        found = locate_template_in_context_hierachy(key=key, path_prefix=self.get_path_prefix(), include_contents=True)
         if not found:
-            raise DSOException(f"Template '{key}' not found nor inherited in the given context: stage={config.short_stage}")
+            raise DSOException(f"Template '{key}' not found nor inherited in the given context: stage={AppConfig.short_stage}")
 
         result = { "Revisions":
             [{
@@ -96,18 +92,17 @@ class LocalTemplateProvider(TemplateProvider):
         return result
 
 
-    def delete(self, config, key):
-        self.config = config
-        Logger.debug(f"Locating template: namespace={config.namespace}, project={config.project}, application={config.application}, stage={config.stage}")
+    def delete(self, key):
+        Logger.debug(f"Locating template: namespace={AppConfig.namespace}, project={AppConfig.project}, application={AppConfig.application}, stage={AppConfig.stage}")
         ### only parameters owned by the context can be deleted, hence uninherited=True
-        found = locate_template_in_context_hierachy(config=config, key=key, path_prefix=self.get_path_prefix(), uninherited=True)
+        found = locate_template_in_context_hierachy(key=key, path_prefix=self.get_path_prefix(), uninherited=True)
         if not found:
             raise DSOException(f"Template '{key}' not found in the given context: stage={Stages.shorten(stage)}")
         Logger.info(f"Deleting template: path={found[key]['Path']}")
         delete_local_template(path=found[key]['Path'])
         result = {
                 'Key': key,
-                'Stage': config.short_stage,
+                'Stage': AppConfig.short_stage,
                 'Scope': found[key]['Scope'], 
                 'Origin': found[key]['Origin'], 
                 'Path': found[key]['Path'],
